HtmlListWidget | django_cradmin API Document

    import HtmlListWidget from 'django_cradmin/scripts/django_cradmin/widgets/HtmlListWidget.jsx'

public class | source

# HtmlListWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → HtmlListWidget

## Constructor Summary

Public Constructor
public | constructor(element: *, widgetInstanceId: *) |

## Method Summary

Public Methods
public | destroy() |

## Public Constructors

### public constructor(element: *, widgetInstanceId: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |
widgetInstanceId | * |  |

## Public Methods

### public destroy() source